searchData={"items":[{"type":"module","title":"XmlBuilder","doc":"A module for generating XML","ref":"XmlBuilder.html"},{"type":"module","title":"Examples - XmlBuilder","doc":"iex> XmlBuilder.document(:person) |> XmlBuilder.generate()\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n \"\n\n    iex> XmlBuilder.document(:person, \"Josh\") |> XmlBuilder.generate()\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n Josh \"\n\n    iex> XmlBuilder.document(:person) |> XmlBuilder.generate(format: :none)\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?> \"\n\n    iex> XmlBuilder.element(:person, \"Josh\") |> XmlBuilder.generate()\n    \" Josh \"\n\n    iex> XmlBuilder.element(:person, %{occupation: \"Developer\"}, \"Josh\") |> XmlBuilder.generate()\n    \" Josh \"","ref":"XmlBuilder.html#module-examples"},{"type":"function","title":"XmlBuilder.doctype/2","doc":"Creates a DOCTYPE declaration with a system or public identifier.","ref":"XmlBuilder.html#doctype/2"},{"type":"function","title":"System Example - XmlBuilder.doctype/2","doc":"Returns a `tuple` in the format `{:doctype, {:system, name, system_identifier}}`.\n\n```elixir\nimport XmlBuilder\n\ndocument([\n  doctype(\"greeting\", system: \"hello.dtd\"),\n  element(:person, \"Josh\")\n]) |> generate()\n```\n\nOutputs\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<!DOCTYPE greeting SYSTEM \"hello.dtd\">\n Josh \n```","ref":"XmlBuilder.html#doctype/2-system-example"},{"type":"function","title":"Public Example - XmlBuilder.doctype/2","doc":"Returns a `tuple` in the format `{:doctype, {:public, name, public_identifier, system_identifier}}`.\n\n```elixir\nimport XmlBuilder\n\ndocument([\n  doctype(\"html\", public: [\"-//W3C//DTD XHTML 1.0 Transitional//EN\",\n                \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\"]),\n  element(:html, \"Hello, world!\")\n]) |> generate()\n```\n\nOutputs\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n Hello, world! \n```","ref":"XmlBuilder.html#doctype/2-public-example"},{"type":"function","title":"XmlBuilder.document/1","doc":"Generate an XML document.\n\nReturns a `binary`.","ref":"XmlBuilder.html#document/1"},{"type":"function","title":"Examples - XmlBuilder.document/1","doc":"iex> XmlBuilder.document(:person) |> XmlBuilder.generate()\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n \"\n\n    iex> XmlBuilder.document(:person, %{id: 1}) |> XmlBuilder.generate()\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n \"\n\n    iex> XmlBuilder.document(:person, %{id: 1}, \"some data\") |> XmlBuilder.generate()\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n some data \"","ref":"XmlBuilder.html#document/1-examples"},{"type":"function","title":"XmlBuilder.document/2","doc":"","ref":"XmlBuilder.html#document/2"},{"type":"function","title":"XmlBuilder.document/3","doc":"","ref":"XmlBuilder.html#document/3"},{"type":"function","title":"XmlBuilder.element/1","doc":"Create an XML element.\n\nReturns a `tuple` in the format `{name, attributes, content | list}`.","ref":"XmlBuilder.html#element/1"},{"type":"function","title":"Examples - XmlBuilder.element/1","doc":"iex> XmlBuilder.element(:person)\n    {:person, nil, nil}\n\n    iex> XmlBuilder.element(:person, \"data\")\n    {:person, nil, \"data\"}\n\n    iex> XmlBuilder.element(:person, %{id: 1})\n    {:person, %{id: 1}, nil}\n\n    iex> XmlBuilder.element(:person, %{id: 1}, \"data\")\n    {:person, %{id: 1}, \"data\"}\n\n    iex> XmlBuilder.element(:person, %{id: 1}, [XmlBuilder.element(:first, \"Steve\"), XmlBuilder.element(:last, \"Jobs\")])\n    {:person, %{id: 1}, [\n      {:first, nil, \"Steve\"},\n      {:last, nil, \"Jobs\"}\n    ]}","ref":"XmlBuilder.html#element/1-examples"},{"type":"function","title":"XmlBuilder.element/2","doc":"","ref":"XmlBuilder.html#element/2"},{"type":"function","title":"XmlBuilder.element/3","doc":"","ref":"XmlBuilder.html#element/3"},{"type":"function","title":"XmlBuilder.generate/2","doc":"Generate a binary from an XML tree. Accepts optional parameters\n\n- `format: Format.Module.Name` to specify the formatter to use,\n  the `format` parameter might be shortened to `:none` and `:indented` for built-in formatters\n- `empty: :full | :squeezed` to not shorten empty tags `  ` to ` `,\n  `:full` will preserve the indentation, `:squeezed` would produce closing tag immediately after\n  the opening one, without spaces\n\nReturns a `binary`.","ref":"XmlBuilder.html#generate/2"},{"type":"function","title":"Examples - XmlBuilder.generate/2","doc":"iex> XmlBuilder.generate(XmlBuilder.element(:person))\n    \" \"\n\n    iex> XmlBuilder.generate({:person, %{id: 1}, \"Steve Jobs\"})\n    \" Steve Jobs \"\n\n    iex> XmlBuilder.generate({:name, nil, [{:first, nil, \"Steve\"}]}, format: :none)\n    \"  Steve  \"\n\n    iex> XmlBuilder.generate({:name, nil, [{:first, nil, \"Steve\"}]})\n    \" \\n   Steve \\n \"\n\n    iex> XmlBuilder.generate(:xml_decl, encoding: \"ISO-8859-1\")\n    ~s|<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>|\n\n    iex> XmlBuilder.generate(\n    ...>  [{:person, %{},\n    ...>    [{:name, %{id: 123}, \"Josh\"},\n    ...>     {:age, %{}, \"21\"}]}], format: XmlBuilder.Format.None)\n    \"  Josh  21  \"\n\n    iex> XmlBuilder.generate(\n    ...>  [{:person, %{},\n    ...>    [{:name, %{id: 123}, \"Josh\"},\n    ...>     {:age, %{}, \"21\"}]}], format: :none)\n    \"  Josh  21  \"","ref":"XmlBuilder.html#generate/2-examples"},{"type":"function","title":"XmlBuilder.generate_iodata/2","doc":"Similar to `generate/2`, but returns `iodata` instead of a `binary`.","ref":"XmlBuilder.html#generate_iodata/2"},{"type":"function","title":"Examples - XmlBuilder.generate_iodata/2","doc":"iex> XmlBuilder.generate_iodata(XmlBuilder.element(:person))\n    [\"\", '<', \"person\", '/>']","ref":"XmlBuilder.html#generate_iodata/2-examples"},{"type":"function","title":"XmlBuilder.postwalk/2","doc":"Performs a depth-first, post-order traversal of _XML_ tree.\n\nReturns a new tree of `XmlBuilder.Element.t()` where each element\n  is the result of invoking fun on each corresponding element.","ref":"XmlBuilder.html#postwalk/2"},{"type":"function","title":"Examples - XmlBuilder.postwalk/2","doc":"iex> XmlBuilder.postwalk(XmlBuilder.element(:person), fn\n    ...>   {x, nil, nil} -> {x, %{}, []}\n    ...> end)\n    {:person, %{}, []}\n\n    iex> XmlBuilder.postwalk({:person, %{id: 1}, \"Steve Jobs\"}, fn\n    ...>   {name, args, _content} -> {name, args, \"Linux Torvalds\"}\n    ...> end)\n    {:person, %{id: 1}, \"Linux Torvalds\"}\n\n    iex> XmlBuilder.postwalk({:name, nil, [{:first, nil, \"Steve\"}]}, fn\n    ...>   {:first, _, _} -> {:first, %{}, \"Linus\"}\n    ...>   e -> e\n    ...> end)\n    {:name, nil, [{:first, %{}, \"Linus\"}]}\n\n    iex> XmlBuilder.postwalk(\n    ...>  [{:person, %{},\n    ...>    [{:name, %{id: 123}, \"Josh\"},\n    ...>     {:age, %{}, \"21\"}]}], fn\n    ...>   {:age, _, _} -> {:age, %{}, \"24\"}\n    ...>   e -> e\n    ...> end)\n    ...> |> hd()\n    ...> |> XmlBuilder.generate(format: XmlBuilder.Format.None)\n    ~s|  Josh  24  |","ref":"XmlBuilder.html#postwalk/2-examples"},{"type":"function","title":"XmlBuilder.postwalk/3","doc":"Performs a depth-first, post-order traversal of _XML_ tree.\n\nReturns a new tree of `XmlBuilder.Element.t()` where each element\n  is the result of invoking fun on each corresponding element.","ref":"XmlBuilder.html#postwalk/3"},{"type":"function","title":"Examples - XmlBuilder.postwalk/3","doc":"iex> XmlBuilder.postwalk(XmlBuilder.element(:person), %{}, fn\n    ...>   {x, nil, nil}, a -> {{x, %{}, []}, a}\n    ...> end)\n    {{:person, %{}, []}, %{}}\n\n    iex> XmlBuilder.postwalk({:person, %{id: 1}, \"Steve Jobs\"}, %{}, fn\n    ...>   {name, args, _content}, a -> {{name, args, \"Linux Torvalds\"}, a}\n    ...> end)\n    {{:person, %{id: 1}, \"Linux Torvalds\"}, %{}}\n\n    iex> XmlBuilder.postwalk({:name, nil, [{:first, nil, \"Steve\"}]}, %{}, fn\n    ...>   {:first, _, value}, a ->\n    ...>     {{:first, %{}, \"Linus\"}, Map.put(a, :first, value)}\n    ...>   e, a ->\n    ...>     {e, a}\n    ...> end)\n    {{:name, nil, [{:first, %{}, \"Linus\"}]}, %{first: \"Steve\"}}\n\n    iex> XmlBuilder.postwalk(\n    ...>  [{:person, %{},\n    ...>    [{:name, %{id: 123}, \"Josh\"},\n    ...>     {:age, %{}, \"21\"}]}], %{}, fn\n    ...>   {:age, _, _}, a -> {{:age, %{}, \"24\"}, a}\n    ...>   e, a -> {e, a}\n    ...> end)\n    ...> |> elem(0)\n    ...> |> hd()\n    ...> |> XmlBuilder.generate(format: XmlBuilder.Format.None)\n    ~s|  Josh  24  |","ref":"XmlBuilder.html#postwalk/3-examples"},{"type":"function","title":"XmlBuilder.prewalk/2","doc":"Performs a depth-first, pre-order traversal of _XML_ tree.\n\nReturns a new tree of `XmlBuilder.Element.t()` where each element\n  is the result of invoking fun on each corresponding element.","ref":"XmlBuilder.html#prewalk/2"},{"type":"function","title":"Examples - XmlBuilder.prewalk/2","doc":"iex> XmlBuilder.prewalk(XmlBuilder.element(:person), fn\n    ...>   {x, nil, nil} -> {x, %{}, []}\n    ...> end)\n    {:person, %{}, []}\n\n    iex> XmlBuilder.prewalk({:person, %{id: 1}, \"Steve Jobs\"}, fn\n    ...>   {name, args, _content} -> {name, args, \"Linux Torvalds\"}\n    ...> end)\n    {:person, %{id: 1}, \"Linux Torvalds\"}\n\n    iex> XmlBuilder.prewalk({:name, nil, [{:first, nil, \"Steve\"}]}, fn\n    ...>   {:first, _, _} -> {:first, %{}, \"Linus\"}\n    ...>   e -> e\n    ...> end)\n    {:name, nil, [{:first, %{}, \"Linus\"}]}\n\n    iex> XmlBuilder.prewalk(\n    ...>  [{:person, %{},\n    ...>    [{:name, %{id: 123}, \"Josh\"},\n    ...>     {:age, %{}, \"21\"}]}], fn\n    ...>   {:age, _, _} -> {:age, %{}, \"24\"}\n    ...>   e -> e\n    ...> end)\n    ...> |> hd()\n    ...> |> XmlBuilder.generate(format: XmlBuilder.Format.None)\n    ~s|  Josh  24  |","ref":"XmlBuilder.html#prewalk/2-examples"},{"type":"function","title":"XmlBuilder.prewalk/3","doc":"Performs a depth-first, pre-order traversal of _XML_ tree.\n\nReturns a new tree of `XmlBuilder.Element.t()` where each element\n  is the result of invoking fun on each corresponding element.","ref":"XmlBuilder.html#prewalk/3"},{"type":"function","title":"Examples - XmlBuilder.prewalk/3","doc":"iex> XmlBuilder.prewalk(XmlBuilder.element(:person), %{}, fn\n    ...>   {x, nil, nil}, a -> {{x, %{}, []}, a}\n    ...> end)\n    {{:person, %{}, []}, %{}}\n\n    iex> XmlBuilder.prewalk({:person, %{id: 1}, \"Steve Jobs\"}, %{}, fn\n    ...>   {name, args, _content}, a -> {{name, args, \"Linux Torvalds\"}, a}\n    ...> end)\n    {{:person, %{id: 1}, \"Linux Torvalds\"}, %{}}\n\n    iex> XmlBuilder.prewalk({:name, nil, [{:first, nil, \"Steve\"}]}, %{}, fn\n    ...>   {:first, _, value}, a ->\n    ...>     {{:first, %{}, \"Linus\"}, Map.put(a, :first, value)}\n    ...>   e, a ->\n    ...>     {e, a}\n    ...> end)\n    {{:name, nil, [{:first, %{}, \"Linus\"}]}, %{first: \"Steve\"}}\n\n    iex> XmlBuilder.prewalk(\n    ...>  [{:person, %{},\n    ...>    [{:name, %{id: 123}, \"Josh\"},\n    ...>     {:age, %{}, \"21\"}]}], %{}, fn\n    ...>   {:age, _, _}, a -> {{:age, %{}, \"24\"}, a}\n    ...>   e, a -> {e, a}\n    ...> end)\n    ...> |> elem(0)\n    ...> |> hd()\n    ...> |> XmlBuilder.generate(format: XmlBuilder.Format.None)\n    ~s|  Josh  24  |","ref":"XmlBuilder.html#prewalk/3-examples"},{"type":"function","title":"XmlBuilder.traverse/4","doc":"Performs a depth-first traversal of _XML_ tree using an accumulator.","ref":"XmlBuilder.html#traverse/4"},{"type":"module","title":"XmlBuilder.Element","doc":"The internal representation of the _XML_ element,\n  responsible for parsing _and_ normalization.\n\nGenerally, you won’t use this internal module.","ref":"XmlBuilder.Element.html"},{"type":"type","title":"XmlBuilder.Element.as_tuple/0","doc":"The raw internal representation of the _XML_ element","ref":"XmlBuilder.Element.html#t:as_tuple/0"},{"type":"type","title":"XmlBuilder.Element.ast/0","doc":"The AST representation of _XML_","ref":"XmlBuilder.Element.html#t:ast/0"},{"type":"type","title":"XmlBuilder.Element.attrs/0","doc":"Attributes of the _XML_ element","ref":"XmlBuilder.Element.html#t:attrs/0"},{"type":"type","title":"XmlBuilder.Element.content/0","doc":"Single inner subelement of the _XML_ element","ref":"XmlBuilder.Element.html#t:content/0"},{"type":"type","title":"XmlBuilder.Element.contents/0","doc":"Whole inner content of the _XML_ element","ref":"XmlBuilder.Element.html#t:contents/0"},{"type":"type","title":"XmlBuilder.Element.name/0","doc":"Name of the _XML_ element","ref":"XmlBuilder.Element.html#t:name/0"},{"type":"type","title":"XmlBuilder.Element.t/0","doc":"The internal representation of the _XML_ element","ref":"XmlBuilder.Element.html#t:t/0"},{"type":"behaviour","title":"XmlBuilder.Format","doc":"Base behaviour for all the formatters. There are two defauls formatters\n  included: `XmlBuilder.Format.None` and `XmlBuilder.Format.Indented`.\n\nTo introduce the new formatter, one should `use XmlBuilder.Format` and\n  possibly override `indent/1` and/or `intersperse/0` implementation(s):\n\n```elixir\ndefmodule MyCuteFormat do\n  use XmlBuilder.Format, indent: \"  \", intersperse: \"\\n\"\nend\n```","ref":"XmlBuilder.Format.html"},{"type":"callback","title":"XmlBuilder.Format.indent/1","doc":"","ref":"XmlBuilder.Format.html#c:indent/1"},{"type":"callback","title":"XmlBuilder.Format.intersperse/0","doc":"","ref":"XmlBuilder.Format.html#c:intersperse/0"},{"type":"module","title":"XmlBuilder.Format.Indented","doc":"Format for `XmlBuilder.generate/2` to produce a human-readable indented XML.\nUnlike `XmlBuilder.Format.None`, this formatter\n  produces a human readable XML, indented with tabs and new lines, like this:\n```xml\n \n   Josh \n   21 \n \n```\n**Normally you should not use this formatter explicitly, pass it as an\noptional parameter to `XmlBuilder.generate/2` instead.**","ref":"XmlBuilder.Format.Indented.html"},{"type":"module","title":"XmlBuilder.Format.None","doc":"Format for `XmlBuilder.generate/2` to produce a machine-readable aka\n  minified XML.\nUnlike `XmlBuilder.Format.Indented`, this formatter does not\n  produce a human readable XML, it simply spits out elements one immediately\nafter another, like this:\n```xml\n  Josh  21  \n```\n\n**Normally you should not use this formatter explicitly, pass it as an\noptional parameter to `XmlBuilder.generate/2` instead.**","ref":"XmlBuilder.Format.None.html"},{"type":"module","title":"XmlBuilder.Format.TabIndented","doc":"Format for `XmlBuilder.generate/2` to produce a human-readable indented XML.\nLike `XmlBuilder.Format.Indented`, but indents the content with tabs instead of spaces.\n\n**Normally you should not use this formatter explicitly, pass it as an\noptional parameter to `XmlBuilder.generate/2` instead.**","ref":"XmlBuilder.Format.TabIndented.html"},{"type":"extras","title":"XML Builder","doc":"XML Builder\n===========\n\n\n[![CI](https://github.com/am-kantox/xml_builder/workflows/mix/badge.svg)](https://github.com/am-kantox/xml_builder/actions)\n[![Module Version](https://img.shields.io/hexpm/v/xml_builder_ex.svg)](https://hex.pm/packages/xml_builder_ex)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/xml_builder_ex/)\n[![Total Download](https://img.shields.io/hexpm/dt/xml_builder_ex.svg)](https://hex.pm/packages/xml_builder_ex)\n[![License](https://img.shields.io/hexpm/l/xml_builder_ex.svg)](https://github.com/am-kantox/xml_builder/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/am-kantox/xml_builder.svg)](https://github.com/am-kantox/xml_builder/commits/master)","ref":"readme.html"},{"type":"extras","title":"🔱 of [`XmlBuilder`](https://github.com/joshnuss/xml_builder) - XML Builder","doc":"This is a fork of `XmlBuilder` originally written by _Joshua Nussbaum_. OIt’s fully backward compatible and adds several goodnesses like `Access` implementation for XML‌ AST, custom formatters, per-element formatters, listeners and `pre-/post-walk` of the resulting AST.\n\nIf in doubt, why would you want to use this fork, please use the original `XmlBuilder` package, it’d suit your needs perfectly fine.","ref":"readme.html#of-xmlbuilder-https-github-com-joshnuss-xml_builder"},{"type":"extras","title":"Overview - XML Builder","doc":"An Elixir library for building XML. It is inspired by the late [Jim Weirich](https://github.com/jimweirich)'s awesome [builder](https://github.com/jimweirich/builder) library for Ruby.\n\nEach XML node is structured as a tuple of name, attributes map, and content/list.\n\n```elixir\n{name, attrs, content | list}\n```","ref":"readme.html#overview"},{"type":"extras","title":"Installation - XML Builder","doc":"Add dependency to your project's `mix.exs`:\n\n```elixir\ndef deps do\n  [{:xml_builder_ex, \"~> 3.1\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Examples - XML Builder","doc":"#","ref":"readme.html#examples"},{"type":"extras","title":"A simple element - XML Builder","doc":"Like ` Josh `, would look like:\n\n```elixir\n{:person, %{id: 12345}, \"Josh\"} |> XmlBuilder.generate()\n```\n\n#","ref":"readme.html#a-simple-element"},{"type":"extras","title":"An element with child elements - XML Builder","doc":"Like `  Josh  Nussbaum  `.\n\n```elixir\n{:person, %{id: 12345}, [{:first, nil, \"Josh\"}, {:last, nil, \"Nussbaum\"}]} |> XmlBuilder.generate()\n```\n\n#","ref":"readme.html#an-element-with-child-elements"},{"type":"extras","title":"Convenience Functions - XML Builder","doc":"For more readability, you can use XmlBuilder's methods instead of creating tuples manually.\n\n```elixir\nXmlBuilder.document(:person, \"Josh\") |> XmlBuilder.generate()\n```\n\nOutputs:\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n Josh \n```\n\n##","ref":"readme.html#convenience-functions"},{"type":"extras","title":"Building up an element - XML Builder","doc":"An element can be built using multiple calls to the `element` function.\n\n```elixir\nimport XmlBuilder\n\ndef person(id, first, last) do\n  element(:person, %{id: id}, [\n    element(:first, first),\n    element(:last, last)\n  ])\nend\n\niex> [person(123, \"Steve\", \"Jobs\"),\n      person(456, \"Steve\", \"Wozniak\")] |> generate()\n```\n\nOutputs.\n\n```xml\n \n   Steve \n   Jobs \n \n \n   Steve \n   Wozniak \n \n```\n\n##","ref":"readme.html#building-up-an-element"},{"type":"extras","title":"Using keyed lists - XML Builder","doc":"The previous example can be simplified using a keyed list.\n\n```elixir\nimport XmlBuilder\n\ndef person(id, first, last) do\n  element(:person, %{id: id}, first: first,\n                              last: last)\nend\n\niex> person(123, \"Josh\", \"Nussbaum\") |> generate(format: :none)\n\"  Josh  Nussbaum  \"\n```\n\n##","ref":"readme.html#using-keyed-lists"},{"type":"extras","title":"Namespaces - XML Builder","doc":"To use a namespace, add an `xmlns` attribute to the root element.\n\nTo use multiple schemas, specify a `xmlns:nsName` attribute for each schema and use a colon `:` in the element name, ie `nsName:elementName`.\n\n```elixir\nimport XmlBuilder\n\niex> generate({:example, [xmlns: \"http://schemas.example.tld/1999\"], \"content\"})\n\" content \"\n\niex> generate({:\"nsName:elementName\", [\"xmlns:nsName\": \"http://schemas.example.tld/1999\"], \"content\"})\n\" content \"\n```\n\n#","ref":"readme.html#namespaces"},{"type":"extras","title":"DOCTYPE declarations - XML Builder","doc":"A DOCTYPE can be declared by applying the `doctype` function at the first position of a list of elements in a `document` definition:\n\n```elixir\nimport XmlBuilder\n\ndocument([\n  doctype(\"html\", public: [\"-//W3C//DTD XHTML 1.0 Transitional//EN\",\n                \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\"]),\n  element(:html, \"Hello, world!\")\n]) |> generate()\n```\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n Hello, world! \n```\n\n#","ref":"readme.html#doctype-declarations"},{"type":"extras","title":"Encoding - XML Builder","doc":"While the output is always UTF-8 and has to be converted in another place, you can override the encoding statement in the XML declaration with the `encoding` option.\n\n```elixir\nimport XmlBuilder\n\ndocument(:oldschool)\n|> generate(encoding: \"ISO-8859-1\")\n|> :unicode.characters_to_binary(:unicode, :latin1)\n```\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n \n```\n\n#","ref":"readme.html#encoding"},{"type":"extras","title":"Using `iodata()` directly - XML Builder","doc":"While by default, output from `generate/2` is converted to `binary()`, you can use `generate_iodata/2` to skip this conversion. This can be convenient if you're using `IO.binwrite/2` on a `:raw` IO device, as these APIs can work with `iodata()` directly, leading to some performance gains.\n\nIn some scenarios, it may be beneficial to generate part of your XML upfront, for instance when generating a `sitemap.xml`, you may have shared fields for `author`. Instead of generating this each time, you could do the following:\n\n```elixir\nimport XmlBuilder\n\nentries = [%{title: \"Test\", url: \"https://example.org/\"}]\n\n# Generate static author data upfront\nauthor = generate_iodata(element(:author, [\n  element(:name, \"John Doe\"),\n  element(:uri, \"https://example.org/\")\n]))\n\nfile = File.open!(\"path/to/file\", [:raw])\n\nfor entry <- entries do\n  iodata =\n    generate_iodata(element(:entry, [\n      # Reuse the static pre-generated fields as-is\n      {:iodata, author},\n\n      # Dynamic elements are generated for each entry\n      element(:title, entry.title),\n      element(:link, entry.url)\n    ]))\n\n  IO.binwrite(file, iodata)\nend\n```\n\n#","ref":"readme.html#using-iodata-directly"},{"type":"extras","title":"Escaping - XML Builder","doc":"XmlBuilder offers 3 distinct ways to control how content of tags is escaped and handled:\n\n- By default, any content is escaped, replacing reserved characters (`& \" ' < >`) with their equivalent entity (`&amp;` etc.)\n- If content is wrapped in `{:cdata, cdata}`, the content in `cdata` is wrapped with `<![CDATA[...]]>`, and not escaped. You should make sure the content itself does not contain `]]>`.\n- If content is wrapped in `{:safe, data}`, the content in `data` is not escaped, but will be stringified if not a bitstring. Use this option carefully. It may be useful when data is guaranteed to be safe (numeric data).\n- If content is wrapped in `{:iodata, data}`, either in the top level or within a list, the `data` is used as `iodata()`, and will not be escaped, indented or stringified. An example of this can be seen in the \"Using `iodata()` directly\" example above.\n\n#","ref":"readme.html#escaping"},{"type":"extras","title":"Standalone - XML Builder","doc":"Should you need `standalone=\"yes\"` in the XML declaration, you can pass `standalone: true` as option to the `generate/2` call.\n\n```elixir\nimport XmlBuilder\n\n:outsider\n|> document()\n|> generate(standalone: true)\n```\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" standalone=\"yes\"?>\n \n```\n\nIf otherwise you need `standalone =\"no\"` in the XML declaration, you can pass `standalone: false` as an option to the` generate / 2` call.\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" standalone=\"no\"?>\n \n```\n\n#","ref":"readme.html#standalone"},{"type":"extras","title":"Formatting - XML Builder","doc":"To remove indentation, pass `format: :none` option to `XmlBuilder.generate/2`.\n\n```elixir\ndoc |> XmlBuilder.generate(format: :none)\n```\n\nThe default is to formatting with indentation, which is equivalent to `XmlBuilder.generate(doc, format: :indent)`.\n\n## `Access`\n\nUse `xml_builder_access` library to get the `Access` implemented for\nthe generated _XML_ tree.\n\n```elixir\n  {:xml_builder_access, \"~> 1.0\"}\n```\n\n* [github](https://github.com/am-kantox/xml_builder_access)\n* [docs](https://hexdocs.pm/xml_builder_access)","ref":"readme.html#formatting"},{"type":"extras","title":"Changelog - XML Builder","doc":"* **`3.1.41`** `Application.get_env(:xml_builder, :arrogant_floats)` and `Application.get_env(:xml_builder, :float_notation)`\n* **`3.1.4`** `empty: :squeezed` option in a call to `XmlBuilder.generate/2`\n* **`3.1.3`** `empty: :full` option in a call to `XmlBuilder.generate/2`\n* **`3.1.0`** `XmlBuilder.{traverse,prewalk,postwalk}`\n* **`3.0.0`** initial fork of the original repo\n* **`3.0.1`** formats, refactoring, specs\n* **`3.1.0`** `XmlBuilder.{pre,post}walk/{2,3}`","ref":"readme.html#changelog"},{"type":"extras","title":"License - XML Builder","doc":"This source code is licensed under the [MIT License](https://github.com/am-kantox/xml_builder/blob/master/LICENSE). Copyright (c) 2014-present, Joshua Nussbaum. All rights reserved.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}